import numpy as np
import argparse

def StrToBool(s):
	if isinstance(s,bool):
		return s
	if s.lower() in ('yes', 'true', 't', 'y', '1'):
		return True
	elif s.lower() in ('no', 'false', 'f', 'n', '0'):
		return False
	else:
		raise argparse.ArgumentTypeError('Boolean value expected.')

def StrToNumpy(s):
	if not s:
		return np.array([])
	else:
		l = list(map(int,s.split(':')))
		return np.array(l) if len(l)==1 else np.arange(l[0],l[1]) if len(l)==2 else np.arange(l[0],l[1],l[2])

def GetTimes(times,n):
	tmax = times.max()
	times = np.array_split(times,n)
	times = [np.array(timei[timei<=tmax]) for timei in times]
	return times

def Header(n):
	print('#!/bin/bash')
	print('#SBATCH --job-name=jobArray')
	print('#SBATCH --partition=intel')
	print('#SBATCH --time=2:00:00')
	print('#SBATCH --mem=16000')
	print('#SBATCH --nodes=1 --ntasks=1')
	print('#SBATCH --array=0-{0:d}'.format(n-1))
	print('#SBATCH --output=log_output_%A_%a')
	print('#SBATCH --error=log_error_%A_%a')
	print('')
	print('echo "  Task ${SLURM_ARRAY_TASK_ID}"')
	print('')
	print('export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$HOME/local/libconfig-1.7.2/lib')
	print('')
	print('cd $SLURM_SUBMIT_DIR')
	print('[ ${{SLURM_ARRAY_TASK_ID}} -eq {0:d} ] && make exportBubbles'.format(0))
	print('while [ ! -f ExportBubbles ]; do sleep 10; done')
	print('')


def Export(taskid,time):
	dt = np.diff(time)[0] if len(time)>1 else 1
	print('if [ ${{SLURM_ARRAY_TASK_ID}} -eq {0:d} ]'.format(taskid))
	print('then')
	print('\t# {0}:{1}:{2} ='.format(time[0],time[-1]+1,dt),time.tolist())
	if dt==1:
		tmin=time[ 0]-1
		tmax=time[-1]+1
		print('\t./ExportBubbles -i Input.in -t {0}:{1}'.format(tmin,tmax))

		tmin=time[ 0]
		tmax=time[-1]+1
		print('\tpython -u main.py -t {0}:{1}'.format(tmin,tmax))
	else:
		for timei in time:
			tmin=timei-1
			tmax=timei+1
			print('\t./ExportBubbles -i input.in -t {0}:{1}'.format(tmin,tmax))

		tmin=time[ 0]
		tmax=time[-1]+1
		print('\tpython -u main.py -t {0}:{1}:{2}'.format(tmin,tmax,dt))
	rm_command = 'rm -vf '
	for t in time.tolist()[:-1]:
		rm_command += ' phi????_{:04d}.vts'.format(t)
	print('\t' + rm_command)
	print('fi')

def Clean():
	print('#!/bin/bash')
	print('#SBATCH --job-name=clean')
	print('#SBATCH --partition=intel')
	print('#SBATCH --time=2:00:00')
	print('#SBATCH --nodes=1 --ntasks=1')
	print('#SBATCH --output=log_output')
	print('#SBATCH --error=log_error')
	print('cd $SLURM_SUBMIT_DIR')
	print('ls -1 | grep -v \'^bb_\' | grep -v \'^bbv_\' | grep -v \'phiWall.vts\' | xargs rm -rv')

parser = argparse.ArgumentParser()
parser.add_argument('-t',type=StrToNumpy,default='240:1200')
parser.add_argument('-np',type=int,default=1)
parser.add_argument('-clean',type=StrToBool,default='n')
args = parser.parse_args()
if args.clean:
	Clean()
else:
	Header(args.np)
	times = GetTimes(args.t,args.np)
	for taskid,time in enumerate(times):
		Export(taskid,time)
